@@ -1620,7 +1620,7 @@ int main(const int argc, const char *argv[])
         if(!envFont)
         {
             /* Pick a default font */
-            snprintf(gOutputFont, bufLen, "Luxi Sans");
+            snprintf(gOutputFont, bufLen, "DejaVu Sans");
         }
         else if(snprintf(gOutputFont, bufLen, "%s", envFont) >= bufLen)
         {
